/*****************************************************************************
 *          Copyright: (C) Copyright David Goodwin, 2014
 *            License: GNU General Public License
 *****************************************************************************
 *
 *   This is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This software is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this software; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 ****************************************************************************/

#ifndef BASICQCPINTERACTIONMANAGER_H
#define BASICQCPINTERACTIONMANAGER_H

#include <QObject>
#include <QPointer>
#include "qcp/qcustomplot.h"

class BasicQCPInteractionManager : public QObject
{
    Q_OBJECT

    Q_PROPERTY(bool yAxisLock READ isYAxisLockEnabled WRITE setYAxisLockEnabled)
public:
    explicit BasicQCPInteractionManager(QCustomPlot* plot, QObject *parent = 0);
    
    bool isYAxisLockEnabled() const { return yAxisLock; }

public slots:
    void setYAxisLockEnabled(bool enabled) { yAxisLock = enabled;}

private slots:
    void mousePress(QMouseEvent* event);
    void mouseMove(QMouseEvent* event);
    void mouseRelease();
    void mouseWheel(QWheelEvent *event);

    void axisSelectionChanged();

private:
    bool isAnyYAxisSelected();
    QPointer<QCPAxis> valueAxisWithSelectedParts();
    QList<QCPAxis*> valueAxes();

    // Axis Lock
    bool yAxisLock;

    // Handles panning
    QPoint mDragStart;
    bool mDragging;
    QMap<QCPAxis*, QCPRange> mDragStartVertRange;

    QPointer<QCustomPlot> plot;
    
};

#endif // BASICQCPINTERACTIONMANAGER_H
