/*****************************************************************************
 *          Copyright: (C) Copyright David Goodwin, 2014
 *            License: GNU General Public License
 *****************************************************************************
 *
 *   This is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This software is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this software; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 ****************************************************************************/

#ifndef DATABASEDATASOURCE_H
#define DATABASEDATASOURCE_H

#include <QSqlDriver>
#include <QVariant>

#include "samplecolumns.h"
#include "sampleset.h"
#include "abstractdatasource.h"

class DatabaseDataSource : public AbstractDataSource
{
    Q_OBJECT
public:
    explicit DatabaseDataSource(QObject *parent = 0);
    ~DatabaseDataSource();

    virtual bool openDevice();
    virtual bool closeDevice();

    virtual void startCollecting();
    virtual void stopCollecting();

    SampleSet fetchSamples(SampleColumns columns, QDateTime start, QDateTime end);

signals:

public slots:
private slots:
    void databaseNotification(const QString& name,
                              QSqlDriver::NotificationSource source,
                              const QVariant& payload);
private:
    int getStationId();

    /*
     * zxweather schema v2 databases are only
     * sort of supported (v1 is fine though)
     */
    bool isZxWeather;
    bool isZxWeatherV2Schema;

    QString zxwStationCode;
    bool useIndoorSensors;

    bool collecting;
};

#endif // DATABASEDATASOURCE_H
